@@ -11,8 +11,8 @@
 
 .localstuff <- new.env()
 
-.localstuff$packageType <- ' pre-release'
-##.localstuff$packageType <- ''
+##.localstuff$packageType <- ' pre-release'
+.localstuff$packageType <- ''
 
 .localstuff$countdetectors <- c('count','polygon','transect','unmarked','telemetry')
 .localstuff$detectionfunctions <-
@@ -601,3 +601,9 @@ rpsvi <- function (capthist)
 
 ################################################################################
 replacedefaults <- function (default, user) replace(default, names(user), user)
+
+trim.ipsecr <- function (object, drop = c('call', 'proxyfn', 'mask', 'sim.lm'), 
+                         keep = NULL) {
+    secr:::trim.default(object, drop = drop, keep = keep)
+}
+############################################################################################
